/*  $Id$
 *
 *  Copyright (c) 2006 Mike Massonnet <mmassonnet@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef NOTES_WINDOW_H
#define NOTES_WINDOW_H

typedef struct
{
    GtkWidget *hbox;
    GtkWidget *label;
    GtkWidget *scroll;
    GtkWidget *text;

    gint id;
}
NotePage;

typedef struct
{
    GtkWidget *window;
    GtkWidget *frame;

    GtkWidget *add;
    GtkWidget *del;
    GtkWidget *move_event_box;
    GtkWidget *title;
    GtkWidget *close;

    GtkWidget *notebook;
    GList *pages;

    GtkWidget *vbox;
    GtkWidget *hbox;

    /* Window geometry */
    gint x, y, w, h;
}
Note;

#endif
